@@ -650,7 +650,7 @@ class Provider(AddressProvider):
         "Південний Судан",
         "Польща",
         "Португалія",
-        "Респу́бліка Півні́чна Македо́нія",
+        "Північна Республіка Македонія",
         "Росія",
         "Руанда",
         "Румунія",
