@@ -4,5 +4,5 @@ from .. import Provider as BankProvider
 class Provider(BankProvider):
     """Implement bank provider for ``nl_NL`` locale."""
 
-    bban_format = '????##########'
-    country_code = 'NL'
+    bban_format = "????##########"
+    country_code = "NL"
